@@ -12,12 +12,11 @@
 #   code for working with views, etc.
 #
 # COPYRIGHT
+#   Copyright 2000-2007 Michael Stevens, Andy Wardley.
+#
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
-# REVISION
-#   $Id: File.pm,v 2.71 2006/05/30 17:01:34 abw Exp $
-#
 #============================================================================
 
 package Template::Plugin::File;
@@ -49,7 +48,7 @@ sub new {
     my ($root, $home, @stat, $abs);
 
     return $class->throw('no file specified')
-	unless defined $path and length $path;
+        unless defined $path and length $path;
 
     # path, dir, name, root, home
 
@@ -142,20 +141,10 @@ sub throw {
     die (Template::Exception->new('File', $error));
 }
 
+1;
+
 __END__
 
-
-#------------------------------------------------------------------------
-# IMPORTANT NOTE
-#   This documentation is generated automatically from source
-#   templates.  Any changes you make here may be lost.
-# 
-#   The 'docsrc' documentation source bundle is available for download
-#   from http://www.template-toolkit.org/docs.html and contains all
-#   the source templates, XML files, scripts, etc., from which the
-#   documentation for the Template Toolkit is built.
-#------------------------------------------------------------------------
-
 =head1 NAME
 
 Template::Plugin::File - Plugin providing information about files
@@ -164,7 +153,7 @@ Template::Plugin::File - Plugin providing information about files
 
     [% USE File(filepath) %]
     [% File.path %]         # full path
-    [% File.name %]	    # filename
+    [% File.name %]         # filename
     [% File.dir %]          # directory
 
 =head1 DESCRIPTION
@@ -180,10 +169,10 @@ A file name or path should be specified as a constructor argument.  e.g.
     [% USE File('foo/bar/baz.html') %]
     [% USE File('/foo/bar/baz.html') %]
 
-The file should exist on the current file system (unless 'nostat'
+The file should exist on the current file system (unless C<nostat>
 option set, see below) as an absolute file when specified with as
-leading '/' as per '/foo/bar/baz.html', or otherwise as one relative
-to the current working directory.  The constructor performs a stat()
+leading 'C</>' as per 'C</foo/bar/baz.html>', or otherwise as one relative
+to the current working directory.  The constructor performs a C<stat()>
 on the file and makes the 13 elements returned available as the plugin
 items:
 
@@ -193,35 +182,35 @@ items:
 e.g.
 
     [% USE File('/foo/bar/baz.html') %]
-
+    
     [% File.mtime %]
     [% File.mode %]
     ...
 
-In addition, the 'user' and 'group' items are set to contain the user
-and group names as returned by calls to getpwuid() and getgrgid() for
-the file 'uid' and 'gid' elements, respectively.  On Win32 platforms
-on which getpwuid() and getgrid() are not available, these values are
+In addition, the C<user> and C<group> items are set to contain the user
+and group names as returned by calls to C<getpwuid()> and C<getgrgid()> for
+the file C<uid> and C<gid> elements, respectively.  On Win32 platforms
+on which C<getpwuid()> and C<getgrid()> are not available, these values are
 undefined.
 
     [% USE File('/tmp/foo.html') %]
-    [% File.uid %]	# e.g. 500
+    [% File.uid %]      # e.g. 500
     [% File.user %]     # e.g. abw
 
-This user/group lookup can be disabled by setting the 'noid' option.
+This user/group lookup can be disabled by setting the C<noid> option.
 
     [% USE File('/tmp/foo.html', noid=1) %]
-    [% File.uid %]	# e.g. 500
+    [% File.uid %]      # e.g. 500
     [% File.user %]     # nothing
 
-The 'isdir' flag will be set if the file is a directory.
+The C<isdir> flag will be set if the file is a directory.
 
     [% USE File('/tmp') %]
-    [% File.isdir %]	# 1
+    [% File.isdir %]    # 1
 
-If the stat() on the file fails (e.g. file doesn't exists, bad
-permission, etc) then the constructor will throw a 'File' exception.
-This can be caught within a TRY...CATCH block.
+If the C<stat()> on the file fails (e.g. file doesn't exists, bad
+permission, etc) then the constructor will throw a C<File> exception.
+This can be caught within a C<TRY...CATCH> block.
 
     [% TRY %]
        [% USE File('/tmp/myfile') %]
@@ -230,12 +219,12 @@ This can be caught within a TRY...CATCH block.
        File error: [% error.info %]
     [% END %]
 
-Note the capitalisation of the exception type, 'File' to indicate an
-error thrown by the 'File' plugin, to distinguish it from a regular
-'file' exception thrown by the Template Toolkit.
+Note the capitalisation of the exception type, 'C<File>', to indicate an
+error thrown by the C<File> plugin, to distinguish it from a regular
+C<file> exception thrown by the Template Toolkit.
 
-Note that the 'File' plugin can also be referenced by the lower case
-name 'file'.  However, exceptions are always thrown of the 'File'
+Note that the C<File> plugin can also be referenced by the lower case
+name 'C<file>'.  However, exceptions are always thrown of the C<File>
 type, regardless of the capitalisation of the plugin named used.
 
     [% USE file('foo.html') %]
@@ -247,104 +236,96 @@ specified for the object created.
     [% USE foo = file('foo.html') %]
     [% foo.mtime %]
 
-The 'nostat' option can be specified to prevent the plugin constructor
-from performing a stat() on the file specified.  In this case, the
+The C<nostat> option can be specified to prevent the plugin constructor
+from performing a C<stat()> on the file specified.  In this case, the
 file does not have to exist in the file system, no attempt will be made
 to verify that it does, and no error will be thrown if it doesn't.
-The entries for the items usually returned by stat() will be set 
+The entries for the items usually returned by C<stat()> will be set 
 empty.
 
     [% USE file('/some/where/over/the/rainbow.html', nostat=1) 
     [% file.mtime %]     # nothing
 
-All File plugins, regardless of the nostat option, have set a number
+=head1 METHODS
+
+All C<File> plugins, regardless of the C<nostat> option, have set a number
 of items relating to the original path specified.
 
-=over 4
-
-=item path
+=head2 path
 
 The full, original file path specified to the constructor.
 
     [% USE file('/foo/bar.html') %]
-    [% file.path %]	# /foo/bar.html
+    [% file.path %]     # /foo/bar.html
 
-=item name
+=head2 name
 
 The name of the file without any leading directories.
 
     [% USE file('/foo/bar.html') %]
-    [% file.name %]	# bar.html
+    [% file.name %]     # bar.html
 
-=item dir
+=head2 dir
 
 The directory element of the path with the filename removed.
 
     [% USE file('/foo/bar.html') %]
-    [% file.name %]	# /foo
+    [% file.name %]     # /foo
 
-=item ext
+=head2 ext
 
 The file extension, if any, appearing at the end of the path following 
-a '.' (not included in the extension).
+a 'C<.>' (not included in the extension).
 
     [% USE file('/foo/bar.html') %]
-    [% file.ext %]	# html
+    [% file.ext %]      # html
 
-=item home
+=head2 home
 
-This contains a string of the form '../..' to represent the upward path
+This contains a string of the form 'C<../..>' to represent the upward path
 from a file to its root directory.
 
     [% USE file('bar.html') %]
-    [% file.home %]	# nothing
-
+    [% file.home %]     # nothing
+    
     [% USE file('foo/bar.html') %]
-    [% file.home %]	# ..
-
+    [% file.home %]     # ..
+    
     [% USE file('foo/bar/baz.html') %]
-    [% file.home %]	# ../..
+    [% file.home %]     # ../..
 
-=item root
+=head2 root
 
-The 'root' item can be specified as a constructor argument, indicating
+The C<root> item can be specified as a constructor argument, indicating
 a root directory in which the named file resides.  This is otherwise
 set empty.
 
     [% USE file('foo/bar.html', root='/tmp') %]
-    [% file.root %]	# /tmp
+    [% file.root %]     # /tmp
 
-=item abs
+=head2 abs
 
 This returns the absolute file path by constructing a path from the 
-'root' and 'path' options.
+C<root> and C<path> options.
 
     [% USE file('foo/bar.html', root='/tmp') %]
-    [% file.path %]	# foo/bar.html
-    [% file.root %]	# /tmp
-    [% file.abs %]	# /tmp/foo/bar.html
+    [% file.path %]     # foo/bar.html
+    [% file.root %]     # /tmp
+    [% file.abs %]      # /tmp/foo/bar.html
 
-=back
-
-In addition, the following method is provided:
-
-=over 4 
-
-=item rel(path)
+=head2 rel(path)
 
 This returns a relative path from the current file to another path specified
-as an argument.  It is constructed by appending the path to the 'home' 
+as an argument.  It is constructed by appending the path to the 'C<home>' 
 item.
 
     [% USE file('foo/bar/baz.html') %]
-    [% file.rel('wiz/waz.html') %]	# ../../wiz/waz.html
-
-=back
+    [% file.rel('wiz/waz.html') %]      # ../../wiz/waz.html
 
 =head1 EXAMPLES
 
     [% USE file('/foo/bar/baz.html') %]
-
+    
     [% file.path  %]      # /foo/bar/baz.html
     [% file.dir   %]      # /foo/bar
     [% file.name  %]      # baz.html
@@ -352,65 +333,59 @@ item.
     [% file.root  %]      # ''
     [% file.abs   %]      # /foo/bar/baz.html
     [% file.ext   %]      # html
-    [% file.mtime %]	  # 987654321
+    [% file.mtime %]      # 987654321
     [% file.atime %]      # 987654321
     [% file.uid   %]      # 500
     [% file.user  %]      # abw
 
     [% USE file('foo.html') %]
-
-    [% file.path %]	      # foo.html
+    
+    [% file.path %]           # foo.html
     [% file.dir  %]       # ''
-    [% file.name %]	      # foo.html
+    [% file.name %]           # foo.html
     [% file.root %]       # ''
     [% file.home %]       # ''
     [% file.abs  %]       # foo.html
 
     [% USE file('foo/bar/baz.html') %]
-
-    [% file.path %]	      # foo/bar/baz.html
+    
+    [% file.path %]           # foo/bar/baz.html
     [% file.dir  %]       # foo/bar
-    [% file.name %]	      # baz.html
+    [% file.name %]           # baz.html
     [% file.root %]       # ''
     [% file.home %]       # ../..
     [% file.abs  %]       # foo/bar/baz.html
 
     [% USE file('foo/bar/baz.html', root='/tmp') %]
-
-    [% file.path %]	      # foo/bar/baz.html
+    
+    [% file.path %]           # foo/bar/baz.html
     [% file.dir  %]       # foo/bar
-    [% file.name %]	      # baz.html
+    [% file.name %]           # baz.html
     [% file.root %]       # /tmp
     [% file.home %]       # ../..
     [% file.abs  %]       # /tmp/foo/bar/baz.html
 
     # calculate other file paths relative to this file and its root
     [% USE file('foo/bar/baz.html', root => '/tmp/tt2') %]
-
-    [% file.path('baz/qux.html') %]	    # ../../baz/qux.html
+    
+    [% file.path('baz/qux.html') %]         # ../../baz/qux.html
     [% file.dir('wiz/woz.html')  %]     # ../../wiz/woz.html
 
-
 =head1 AUTHORS
 
-Michael Stevens E<lt>michael@etla.orgE<gt> wrote the original Directory plugin
-on which this is based.  Andy Wardley E<lt>abw@wardley.orgE<gt> split it into 
-separate File and Directory plugins, added some extra code and documentation
-for VIEW support, and made a few other minor tweaks.
-
-=head1 VERSION
-
-2.71, distributed as part of the
-Template Toolkit version 2.18, released on 09 February 2007.
-
-
+Michael Stevens wrote the original C<Directory> plugin on which this is based.
+Andy Wardley split it into separate C<File> and C<Directory> plugins, added
+some extra code and documentation for C<VIEW> support, and made a few other
+minor tweaks.
 
 =head1 COPYRIGHT
 
+Copyright 2000-2007 Michael Stevens, Andy Wardley.
+
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Template::Plugin|Template::Plugin>, L<Template::Plugin::Directory|Template::Plugin::Directory>, L<Template::View|Template::View>
+L<Template::Plugin>, L<Template::Plugin::Directory>, L<Template::View>
 
