@@ -11,7 +11,7 @@
 #   Andy Wardley   <abw@wardley.org>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2007 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 2001-2009 Andy Wardley.  All Rights Reserved.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
@@ -26,7 +26,7 @@ use base 'Template::Plugin';
 use Scalar::Util 'weaken';
 
 
-our $VERSION = 1.37;
+our $VERSION = 1.38;
 our $DYNAMIC = 0 unless defined $DYNAMIC;
 
 
@@ -63,13 +63,21 @@ sub init {
 sub factory {
     my $self = shift;
     my $this = $self;
-    weaken($this);
+    
+    # This causes problems: https://rt.cpan.org/Ticket/Display.html?id=46691
+    # If the plugin is loaded twice in different templates (one INCLUDEd into
+    # another) then the filter gets garbage collected when the inner template 
+    # ends (at least, I think that's what's happening).  So I'm going to take
+    # the "suck it and see" approach, comment it out, and wait for someone to
+    # complain that this module is leaking memory.  
+    
+    # weaken($this);
 
     if ($self->{ _DYNAMIC }) {
         return $self->{ _DYNAMIC_FILTER } ||= [ sub {
             my ($context, @args) = @_;
             my $config = ref $args[-1] eq 'HASH' ? pop(@args) : { };
-        
+
             return sub {
                 $this->filter(shift, \@args, $config);
             };
@@ -106,7 +114,7 @@ sub merge_args {
 
 sub install_filter {
     my ($self, $name) = @_;
-    $self->{ _CONTEXT }->define_filter( $name => $self->factory() );
+    $self->{ _CONTEXT }->define_filter( $name => $self->factory );
     return $self;
 }
 
